python-opentree
===============
[![Build Status](https://travis-ci.org/OpenTreeOfLife/python-opentree.svg?branch=master)](https://travis-ci.org/OpenTreeOfLife/python-opentree) [![Documentation](https://readthedocs.org/projects/opentree/badge/?version=latest&style=flat)](https://opentree.readthedocs.io/en/latest/) [![codecov](https://codecov.io/gh/OpenTreeOfLife/python-opentree/branch/main/graph/badge.svg)](https://codecov.io/gh/OpenTreeOfLife/python-opentree) [![NSF-1759846](https://img.shields.io/badge/NSF-1759846-blue.svg)](https://nsf.gov/awardsearch/showAward?AWD_ID=1759846) [![NSF-1759838](https://img.shields.io/badge/NSF-1759838-blue.svg)](https://nsf.gov/awardsearch/showAward?AWD_ID=1759838) 

This package is a python library designed to make it easier to work with web services and
data resources associated with the [Open Tree of Life](https://opentreeoflife.github.io)
project.
The git repo is at https://github.com/OpenTreeOfLife/python-opentree.


Please refer to [this markdown document](INSTALL.md) or opentree’s documentation website https://opentree.readthedocs.io/en/latest/install.html for more details on installation instructions, function usage, running tutorials, real life examples, and tools for developers.

If you have questions or comments, submit a GitHub issue or email ejmctavish  ucmerced.edu.


For examples scripts see: https://opentree.readthedocs.io/en/latest/running_examples.html


For example Jupyter notebooks see: https://opentree.readthedocs.io/en/latest/notebooks.html

SSB 2020 workshop curriculum is posted at:
[Open Tree workshop](https://opentreeoflife.github.io/SSBworkshop)
at the [2020 SSB Meeting](https://systbiol.github.io/ssb2020/) in Gainesville, FL.

